pub struct IntegrationEvent { /* private fields */ }Expand description
Redaction-safe lifecycle event emitted by an integration adapter.
Implementations
Sourceimpl IntegrationEvent
impl IntegrationEvent
Sourcepub fn new(
adapter: &'static str,
operation: &'static str,
status: IntegrationStatus,
duration: Duration,
) -> Self
pub fn new( adapter: &'static str, operation: &'static str, status: IntegrationStatus, duration: Duration, ) -> Self
Creates a lifecycle event using stable adapter and operation names.
Sourcepub fn correlation_id(self, correlation_id: impl Into<String>) -> Result<Self>
pub fn correlation_id(self, correlation_id: impl Into<String>) -> Result<Self>
Adds a bounded correlation identifier when it is valid.
Sourcepub const fn status(&self) -> IntegrationStatus
pub const fn status(&self) -> IntegrationStatus
Returns the operation outcome.
Sourcepub fn correlation_id_value(&self) -> Option<&str>
pub fn correlation_id_value(&self) -> Option<&str>
Returns the correlation identifier, when present.